import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart' show rootBundle;
import 'package:jsonsample/json_model.dart';
import 'package:syncfusion_flutter_charts/charts.dart';

void main() {
  return runApp(ChartApp());
}

class ChartApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Chart Demo',
      theme: ThemeData(primarySwatch: Colors.blue),
      home: MyHomePage(),
    );
  }
}

class MyHomePage extends StatefulWidget {
  // ignore: prefer_const_constructors_in_immutables
  MyHomePage();

  @override
  _MyHomePageState createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  List<SampleData> chartData = [];
  String? xValue;
  int? yValue;

  Future loadSalesData() async {

    // Read the JSON file decode to jsonResponse
    final String jsonString = await getJsonFromAssets();
    final jsonResponse = json.decode(jsonString);

    // Using the FullData class' .fromJson() method, you can be able to retrieve the all the JSON index data
    FullData fullData = FullData.fromJson(jsonResponse);

    // Here, we have directly used the first index for retrieving the data as there is only one data.
    // You can use also loops to parse through the lists.
    print(fullData.data0![0].data1![0].data2![0].values![0].key);
    print(fullData.data0![0].data1![0].data2![0].values![0].value);

    // Setting the key and value data for mapping in the chart widget.
    xValue = fullData.data0![0].data1![0].data2![0].values![0].key;
    yValue = fullData.data0![0].data1![0].data2![0].values![0].value;

    // Adding the data to the chart widget.
    chartData.add(SampleData(xValue!, yValue!));
  }

  Future<String> getJsonFromAssets() async {
    return await rootBundle.loadString('assets/data.json');
  }

  @override
  void initState() {
    loadSalesData();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
    appBar: AppBar(
      title: const Text('Syncfusion Flutter chart'),
    ),
    body: Center(
        child: FutureBuilder(
            future: getJsonFromAssets(),
            builder: (context, snapshot) {
              if (snapshot.hasData) {
                return SfCartesianChart(
                    primaryXAxis: CategoryAxis(),
                    primaryYAxis: NumericAxis(interval: 500),
                    series: <ChartSeries<SampleData, String>>[
                      ColumnSeries<SampleData, String>(
                        dataSource: chartData,
                        xValueMapper: (SampleData sales, _) => sales.x,
                        yValueMapper: (SampleData sales, _) => sales.y,
                        dataLabelSettings: DataLabelSettings(isVisible: true)
                      )
                    ]);
              } else {
                return Card(
                  elevation: 5.0,
                  child: Container(
                    height: 100,
                    width: 400,
                    child: Center(
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.spaceAround,
                        children: [
                          Text('Retriving JSON data...',
                              style: TextStyle(fontSize: 20.0)),
                          Container(
                            height: 40,
                            width: 40,
                            child: CircularProgressIndicator(
                              semanticsLabel: 'Retriving JSON data',
                              valueColor: AlwaysStoppedAnimation<Color>(
                                  Colors.blueAccent),
                              backgroundColor: Colors.grey[300],
                            ),
                          ),
                        ],
                      ),
                    ),
                  ),
                );
              }
            })));
  }
}

class SampleData {
  SampleData(this.x, this.y);

  final String x;
  final num y;
}
